@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -82,7 +82,7 @@ import com.openexchange.spamhandler.spamassassin.property.PropertyHandler;
  */
 public final class SpamAssassinSpamHandler extends SpamHandler {
 
-    private class PlainAndNestedMessages {
+    private static class PlainAndNestedMessages {
         
         private final String[] nestedMessages;
         
@@ -106,7 +106,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
         
     }
 
-    private class SpamdSettings {
+    private static class SpamdSettings {
 
         private final String hostname;
         
